<?php

namespace Litecms\Profile1\Providers;

use Illuminate\Support\ServiceProvider;

class Profile1ServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'profile1');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'profile1');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.profile1', function ($app) {
            return $this->app->make('Litecms\Profile1\Profile1');
        });

                // Bind Profile to repository
        $this->app->bind(
            'Litecms\Profile1\Interfaces\ProfileRepositoryInterface',
            \Litecms\Profile1\Repositories\Eloquent\ProfileRepository::class
        );

        $this->app->register(\Litecms\Profile1\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Profile1\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.profile1'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/profile1.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/profile1')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/profile1')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
